diff --git a/core/lib/Drupal/Core/Entity/DatabaseStorageControllerNG.php b/core/lib/Drupal/Core/Entity/DatabaseStorageControllerNG.php
index 3f30191..2926bbc 100644
--- a/core/lib/Drupal/Core/Entity/DatabaseStorageControllerNG.php
+++ b/core/lib/Drupal/Core/Entity/DatabaseStorageControllerNG.php
@@ -233,8 +233,8 @@ protected function attachPropertyData(&$queried_entities, $load_revision = FALSE
 
       foreach ($data as $values) {
         $id = $values[$this->idKey];
-        // Field values in default language are stored with
-        // LANGUAGE_DEFAULT as key.
+        // Field values in default language are stored with LANGUAGE_DEFAULT as
+        // key.
         $langcode = empty($values['default_langcode']) ? $values['langcode'] : LANGUAGE_DEFAULT;
 
         foreach ($this->entityInfo['schema_fields_sql']['data_table'] as $name) {
@@ -281,7 +281,7 @@ public function save(EntityInterface $entity) {
           $record->{$this->revisionKey} = $this->saveRevision($entity);
         }
         if ($this->dataTable) {
-          $this->saveData($entity);
+          $this->storePropertyData($entity);
         }
         $this->resetCache(array($entity->id()));
         $this->postSave($entity, TRUE);
@@ -295,7 +295,7 @@ public function save(EntityInterface $entity) {
         }
         $entity->{$this->idKey}->value = $record->{$this->idKey};
         if ($this->dataTable) {
-          $this->saveData($entity);
+          $this->storePropertyData($entity);
         }
 
         // Reset general caches, but keep caches specific to certain entities.
@@ -359,12 +359,12 @@ protected function saveRevision(EntityInterface $entity) {
   }
 
   /**
-   * Saves the entity property data language aware.
+   * Stores the entity property language-aware data.
    *
    * @param \Drupal\Core\Entity\EntityInterface $entity
    *   The entity object.
    */
-  protected function saveData(EntityInterface $entity) {
+  protected function storePropertyData(EntityInterface $entity) {
     // Delete and insert to handle removed values.
     db_delete($this->dataTable)
       ->condition($this->idKey, $entity->id())
@@ -374,7 +374,6 @@ protected function saveData(EntityInterface $entity) {
 
     foreach ($entity->getTranslationLanguages() as $langcode => $language) {
       $record = $this->mapToDataStorageRecord($entity, $langcode);
-
       $values = (array) $record;
       $query
         ->fields(array_keys($values))
@@ -457,7 +456,8 @@ protected function mapToRevisionStorageRecord(EntityInterface $entity) {
    */
   protected function mapToDataStorageRecord(EntityInterface $entity, $langcode) {
     $default_langcode = $entity->language()->langcode;
-    // Don't use strict mode, that way there's no need to do checks here.
+    // Don't use strict mode, this way there's no need to do checks here, as
+    // non-translatable properties are replicated for each language.
     $translation = $entity->getTranslation($langcode, FALSE);
 
     $record = new \stdClass();
diff --git a/core/modules/system/tests/modules/entity_test/entity_test.install b/core/modules/system/tests/modules/entity_test/entity_test.install
index 8fed8b2..dacd1f5 100644
--- a/core/modules/system/tests/modules/entity_test/entity_test.install
+++ b/core/modules/system/tests/modules/entity_test/entity_test.install
@@ -77,7 +77,7 @@ function entity_test_schema() {
         'unsigned' => TRUE,
         'not null' => FALSE,
         'default' => NULL,
-        'description' => "The {users}.uid of the associated user.",
+        'description' => 'The {users}.uid of the associated user.',
       ),
     ),
     'primary key' => array('id'),
@@ -162,7 +162,7 @@ function entity_test_schema() {
         'unsigned' => TRUE,
         'not null' => FALSE,
         'default' => NULL,
-        'description' => "The {users}.uid of the associated user.",
+        'description' => 'The {users}.uid of the associated user.',
       ),
     ),
     'indexes' => array(
@@ -237,7 +237,7 @@ function entity_test_schema() {
         'unsigned' => TRUE,
         'not null' => FALSE,
         'default' => NULL,
-        'description' => "The {users}.uid of the associated user.",
+        'description' => 'The {users}.uid of the associated user.',
       ),
     ),
     'indexes' => array(
@@ -326,7 +326,7 @@ function entity_test_schema() {
         'unsigned' => TRUE,
         'not null' => FALSE,
         'default' => NULL,
-        'description' => "The {users}.uid of the associated user.",
+        'description' => 'The {users}.uid of the associated user.',
       ),
     ),
     'indexes' => array(
@@ -378,7 +378,7 @@ function entity_test_schema() {
         'unsigned' => TRUE,
         'not null' => FALSE,
         'default' => NULL,
-        'description' => "The {users}.uid of the associated user.",
+        'description' => 'The {users}.uid of the associated user.',
       ),
     ),
     'indexes' => array(
diff --git a/core/modules/system/tests/modules/entity_test/entity_test.module b/core/modules/system/tests/modules/entity_test/entity_test.module
index 8226247..f183ccc 100644
--- a/core/modules/system/tests/modules/entity_test/entity_test.module
+++ b/core/modules/system/tests/modules/entity_test/entity_test.module
@@ -8,9 +8,9 @@
 use Drupal\Core\Entity\EntityInterface;
 
 /**
- * Filter that limits test entity list to revisionable ones.
+ * Filter that limits test entity list to revisable ones.
  */
-const ENTITY_TEST_TYPES_REVISIONABLE = 1;
+const ENTITY_TEST_TYPES_REVISABLE = 1;
 
 /**
  * Filter that limits test entity list to multilingual ones.
@@ -18,12 +18,20 @@
 const ENTITY_TEST_TYPES_MULTILINGUAL = 2;
 
 /**
- * Returns the a list of entity types to deal with.
+ * Returns a list of test entity types.
  *
- * @param int $limit
- *   Either ENTITY_TEST_TYPES_REVISIONABLE to only return revisionable entity
- *   types or ENTITY_TEST_TYPES_MULTILINGUAL to only return multilingual ones.
- *   Defaults to NULL, which returns all.
+ * The returned entity types are one for each available entity storage type:
+ * - The plain entity_test type supports neither revisions nor multilingual
+ *   properties.
+ * - The entity_test_mul type supports multilingual properties.
+ * - The entity_test_rev type supports revisions.
+ * - The entity_test_mulrev type supports both revisions and multilingual
+ *   properties.
+ *
+ * @param int $filter
+ *   Either ENTITY_TEST_TYPES_REVISABLE to only return revisable entity types or
+ *   ENTITY_TEST_TYPES_MULTILINGUAL to only return multilingual ones. Defaults
+ *   to NULL, which returns all.
  *
  * @return array
  *   List with entity_types.
@@ -33,7 +41,7 @@ function entity_test_entity_types($filter = NULL) {
   if ($filter == NULL) {
     $types[] = 'entity_test';
   }
-  if ($filter != ENTITY_TEST_TYPES_REVISIONABLE) {
+  if ($filter != ENTITY_TEST_TYPES_REVISABLE) {
     $types[] = 'entity_test_mul';
   }
   if ($filter != ENTITY_TEST_TYPES_MULTILINGUAL) {

diff --git a/core/modules/system/lib/Drupal/system/Tests/Entity/EntityRevisionsTest.php b/core/modules/system/lib/Drupal/system/Tests/Entity/EntityRevisionsTest.php
index dcde970..152527b 100644
--- a/core/modules/system/lib/Drupal/system/Tests/Entity/EntityRevisionsTest.php
+++ b/core/modules/system/lib/Drupal/system/Tests/Entity/EntityRevisionsTest.php
@@ -47,8 +47,8 @@ public function setUp() {
    */
   public function testRevisions() {
 
-    // All revisionable entity variations have to have the same results.
-    foreach (entity_test_entity_types(ENTITY_TEST_TYPES_REVISIONABLE) as $entity_type) {
+    // All revisable entity variations have to have the same results.
+    foreach (entity_test_entity_types(ENTITY_TEST_TYPES_REVISABLE) as $entity_type) {
       $this->assertRevisions($entity_type);
     }
   }